<?php
/**
 * @copyright Copyright (c) 2024 Val Jossic <val@framasoft.org>
 *
 * @author Val Jossic <val@framasoft.org>
 *
 * @license AGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\OwnershipTransfer\Controller;

use OCA\OwnershipTransfer\AppInfo\Application;
use OCA\OwnershipTransfer\Service\ContactsService;
use OCP\AppFramework\Http;
use OCP\AppFramework\Http\DataResponse;
use OCP\AppFramework\OCSController;
use OCP\IRequest;
use OCP\IUserManager;

/** @psalm-suppress UnusedClass */
class ContactsController extends OCSController {

	public const PRINCIPALS_URI = 'principals/users/';

	public function __construct(
		IRequest $request,
		private IUserManager $userManager,
		private ContactsService $contactsService,
	) {
		parent::__construct(Application::APP_ID, $request);
	}

	/**
	 * Get a list of an user's address books
	 *
	 * @param string $userId the id of the user
	 * @return DataResponse<Http::STATUS_OK, array, array<string, mixed>>|DataResponse<Http::STATUS_BAD_REQUEST, array{message: string}, array<string, mixed>>
	 *
	 * 200: returns the list of address books
	 * 400: user doesn't exists
	 *
	 * @IgnoreOpenAPI
	 */
	public function getUserAddressBooks(string $userId): DataResponse {
		$user = $this->userManager->get($userId);

		if ($user == null) {
			return new DataResponse(['message' => "Couldn't fetch the user"], Http::STATUS_BAD_REQUEST);
		}

		$addressBooks = $this->contactsService->getAddressBooks($userId);

		return new DataResponse($addressBooks);
	}
}
